@@ -129,7 +129,7 @@ design <- function(formula = NULL,factors = NULL,Rlevels = NULL,model,data=NULL,
     message(paste0("Parameter(s) ", paste0(not_specified, collapse = ", "), " not specified in formula and assumed constant."))
     additional_constants <- p_types[not_specified]
     names(additional_constants) <- not_specified
-    constants <- c(constants, additional_constants)
+    constants <- c(constants, additional_constants[!names(additional_constants) %in% names(constants)])
     for(add_constant in not_specified) formula[[length(formula)+ 1]] <- as.formula(paste0(add_constant, "~ 1"))
   }
   if(!"subjects" %in% names(factors)) stop("make sure subjects identifier is present in data")
@@ -280,10 +280,16 @@ if (type=="DDM") {
     datar <- datar[order(rep(1:dim(data)[1],nacc),datar$lR),]
     if (!is.null(matchfun)) {
       lM <- matchfun(datar)
-      # if (any(is.na(lM)) || !(is.logical(lM)))
-      #   stop("matchfun not scoring properly")
-      datar$lM <- factor(lM)
+      if (!is.factor(lM))
+        datar$lM <- factor(lM) else
+        datar$lM <- factor(lM,levels=levels(lM))
     }
+    # if (!is.null(matchfun)) {
+    #   lM <- matchfun(datar)
+    #   # if (any(is.na(lM)) || !(is.logical(lM)))
+    #   #   stop("matchfun not scoring properly")
+    #   datar$lM <- factor(lM)
+    # }
     # Advantage NAFC
     nam <- unlist(lapply(strsplit(dimnames(datar)[[2]],"lS"),function(x)x[[1]]))
     islS <- nam ==""
