@@ -53,11 +53,11 @@ add_prior_names <- function(prior, design, ...){
       }
     } else{
       if(length(pnames) == nrow(prior[[pri]])){
-        prior[[pri]] <- prior[[pri]][!nuisance,]
+        prior[[pri]] <- prior[[pri]][!nuisance,,drop=FALSE]
         rownames(prior[[pri]]) <- pnames[!nuisance]
       }
       if(length(pnames) == ncol(prior[[pri]])){
-        prior[[pri]] <- prior[[pri]][,!nuisance]
+        prior[[pri]] <- prior[[pri]][,!nuisance,drop=FALSE]
         colnames(prior[[pri]]) <- pnames[!nuisance]
       }
     }
